@@ -1,5 +1,6 @@
 from ._s3_client import _get_bucket, _load_from_bucket, _exists_in_bucket
 from ._azure_client import _get_container, _load_from_container, _exists_in_container
+from ._local_client import _get_folder, _load_from_folder, _exists_in_folder
 
 
 def _load_from_storage(filepath: str, glossary: bool = False):
@@ -7,6 +8,8 @@ def _load_from_storage(filepath: str, glossary: bool = False):
         return _load_from_bucket(_get_bucket(glossary), filepath)
     if _get_container(glossary):
         return _load_from_container(_get_container(glossary), filepath)
+    if _get_folder(glossary):
+        return _load_from_folder(_get_folder(glossary), filepath)
     raise ImportError
 
 
@@ -15,4 +18,6 @@ def _exists(filepath: str):
         return _exists_in_bucket(_get_bucket(), filepath)
     if _get_container():
         return _exists_in_container(_get_container(), filepath)
+    if _get_folder():
+        return _exists_in_folder(_get_folder(), filepath)
     raise ImportError
